@@ -20,6 +20,7 @@ import numpy as np
 from sklearn.base import BaseEstimator
 from sklearn.discriminant_analysis import LinearDiscriminantAnalysis
 from sklearn.dummy import DummyClassifier
+from sklearn.exceptions import ConvergenceWarning
 from sklearn.utils.validation import check_is_fitted
 
 from ..basis import Identity
@@ -38,6 +39,35 @@ class SSPOC(BaseEstimator):
     As the name suggests, this class can be used to select optimal sensor
     locations (measurement locations) for classification tasks.
 
+    The time complexity of the SSPOC algorithm can be decomposed as
+
+    .. math::
+
+        C_{total} = C_{basis} + C_{classification} + C_{optimization}
+
+    * :math:`C_{basis}`: the complexity of fitting the selected basis object
+      and producing the matrix inverse. The matrix inverse is "free" to compute
+      for :class:`pysensors.basis.Identity` and :class:`pysensors.basis.SVD`.
+      For :class:`pysensors.basis.RandomProjection` the complexity is that
+      of calling :code:`numpy.linalg.pinv` on a matrix of size
+      :code:`n_input_features * n_basis_modes`.
+    * :math:`C_{classification}`: the cost of fitting the chosen classifier
+      to :code:`n_examples` examples with :code:`n_basis_modes` features.
+    * :math:`C_{optimization}`: the cost of solving the sensor optimization
+      problem. For binary classification we use
+      :code:`sklearn.linear_model.OrthogonalMatchingPursuit`.
+      For multi-class classification we use
+      :code:`sklearn.linear_model.MultiTaskLasso`.
+      The costs for each depend on the fit options that are specified.
+      In both cases there are :code:`n_basis_modes` examples
+      with :code:`n_features` features.
+
+    The space complexity likewise depends on the same three factors.
+    Generally, the basis requires :code:`O(n_basis_modes * n_features)`
+    space. The space requirements for classification and optimization depend
+    on the particular algorithms being employed. See the Scikit-learn
+    documentation for specifics.
+
     See the following reference for more information:
 
         Brunton, Bingni W., et al.
@@ -189,9 +219,11 @@ class SSPOC(BaseEstimator):
         else:
             x = validate_input(x)
 
-            with warnings.catch_warnings():
-                action = "ignore" if quiet else "default"
-                warnings.filterwarnings(action, category=UserWarning)
+            if quiet:
+                with warnings.catch_warnings():
+                    warnings.filterwarnings("ignore", category=UserWarning)
+                    self.basis.fit(x)
+            else:
                 self.basis.fit(x)
 
         # Get matrix representation of basis - this is \Psi^T in the paper
@@ -200,19 +232,28 @@ class SSPOC(BaseEstimator):
         )
 
         # Find weight vector
-        with warnings.catch_warnings():
-            action = "ignore" if quiet else "default"
-            warnings.filterwarnings(action, category=UserWarning)
+        if quiet:
+            with warnings.catch_warnings():
+                warnings.filterwarnings("ignore", category=UserWarning)
+                warnings.filterwarnings("ignore", category=ConvergenceWarning)
+                self.classifier.fit(np.matmul(x, self.basis_matrix_inverse_.T), y)
+        else:
             self.classifier.fit(np.matmul(x, self.basis_matrix_inverse_.T), y)
 
         w = np.squeeze(self.classifier.coef_).T
 
         n_classes = len(set(y[:]))
         if n_classes == 2:
-            s = constrained_binary_solve(w, self.basis_matrix_inverse_, **optimizer_kws)
+            s = constrained_binary_solve(
+                w, self.basis_matrix_inverse_, quiet=quiet, **optimizer_kws
+            )
         else:
             s = constrained_multiclass_solve(
-                w, self.basis_matrix_inverse_, alpha=self.l1_penalty, **optimizer_kws
+                w,
+                self.basis_matrix_inverse_,
+                alpha=self.l1_penalty,
+                quiet=quiet,
+                **optimizer_kws,
             )
 
         if self.threshold is None:
@@ -386,7 +427,15 @@ class SSPOC(BaseEstimator):
         if xy is not None:
             if self.n_sensors > 0:
                 x, y = xy
-                self.classifier.fit(x[:, self.sparse_sensors_], y)
+
+                if quiet:
+                    # Suppress warnings arising from no sensors being selected
+                    with warnings.catch_warnings():
+                        warnings.filterwarnings("ignore", category=UserWarning)
+                        warnings.filterwarnings("ignore", category=ConvergenceWarning)
+                        self.classifier.fit(x[:, self.sparse_sensors_], y)
+                else:
+                    self.classifier.fit(x[:, self.sparse_sensors_], y)
                 self.refit_ = True
             else:
                 warnings.warn("No selected sensors; model was not refit.")
